==> httpmaid-websockets-events-0.9.0-sources.jar: de/quantummaid/httpmaid/websocketsevents/IncomingEventMapping.java <==
/*
 * Copyright (c) 2019 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.websocketsevents;

import de.quantummaid.httpmaid.websockets.WebSocketForEventFilter;
import de.quantummaid.messagemaid.processingContext.EventType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import static de.quantummaid.httpmaid.util.Validators.validateNotNull;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class IncomingEventMapping {
    private final EventType eventType;
    private final WebSocketForEventFilter filter;

    static IncomingEventMapping incomingEventMapping(final EventType eventType, final WebSocketForEventFilter filter) {
        validateNotNull(eventType, "eventType");
        validateNotNull(filter, "filter");
        return new IncomingEventMapping(eventType, filter);
    }

    @SuppressWarnings("unchecked")
    public WebSocketForEventFilter filter() {
        return filter;
    }

    public EventType eventType() {
        return eventType;
    }
}

==> httpmaid-websockets-events-0.9.24-sources.jar: de/quantummaid/httpmaid/websocketsevents/IncomingEventMapping.java <==
/*
 * Copyright (c) 2020 Richard Hauswald - https://quantummaid.de/.
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package de.quantummaid.httpmaid.websocketsevents;

import de.quantummaid.httpmaid.websockets.WebSocketForEventFilter;
import de.quantummaid.eventmaid.processingContext.EventType;
import lombok.AccessLevel;
import lombok.EqualsAndHashCode;
import lombok.RequiredArgsConstructor;
import lombok.ToString;

import static de.quantummaid.httpmaid.util.Validators.validateNotNull;

@ToString
@EqualsAndHashCode
@RequiredArgsConstructor(access = AccessLevel.PRIVATE)
public final class IncomingEventMapping {
    private final EventType eventType;
    private final WebSocketForEventFilter filter;

    static IncomingEventMapping incomingEventMapping(final EventType eventType, final WebSocketForEventFilter filter) {
        validateNotNull(eventType, "eventType");
        validateNotNull(filter, "filter");
        return new IncomingEventMapping(eventType, filter);
    }

    @SuppressWarnings("unchecked")
    public WebSocketForEventFilter filter() {
        return filter;
    }

    public EventType eventType() {
        return eventType;
    }
}
